package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````8YP$"#0```!DL@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0(K*T`
M`*RM```%`````!````$```#HK@``Z#X%".@^!0A$`@``K!(```8`````$```
M`@```/2N``#T/@4(]#X%"`@!```(`0``!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&1PIP``<"<%"'`G!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DZ*X`
M`.@^!0CH/@4(&`$``!@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````#```````````````$````%`````,```!'
M3E4`MP&C2UIL07^AVC35S&;A9J=]?$AA````:P```````````````````#T`
M`````````````#4`````````*P```#\````:`````````"`````9````3P``
M```````0````6````$L````Z````9````&`````J````-P``````````````
M#P```%T```!```````````````!?````:0```"D````V`````````$@```!J
M`````````#$`````````,P````````!H````5````$<```!"````````````
M``!A````$0```$8````6``````````````!G````'P```"T````B````````
M```````)`````````"8`````````````````````````!P```$$````^````
M.0```",```!*``````````````!3````90```"<````%````.P````8````R
M`````````$0```````````````````!,````7``````````H````60```"4`
M``!#````30```"P``````````````````````````````%<`````````````
M`````````````````%$```````````````(`````````````````````````
M``````````!6````$@```!,`````````````````````````3@``````````
M````#0``````````````'````&,```!:`````````!4```!;`````````%X`
M```````````````````;````"```````````````%````"\`````````'@``
M````````````&``````````!````8@```%4```````````````````!2````
M.````!T```!F`````````$4`````````(0```````````````````#P`````
M`````````"X````,````````````````````````````````````"@``````
M``````````````````!0```````````````D````%P```#````!)````````
M``````````````````0````T``````````,````.````"P```"4```!%````
M"`````@`````'!`$)4`$@C@!0`&BA@&HP`$``DLH!"DXHC)'B@0,"$4```!'
M````````````````````20```$L```!,`````````$T```!.````4````%$`
M``!2````4P````````!5``````````````!6````5P```%H`````````````
M`%L```!=````7@```&``````````8@```&0``````````````&8```!G````
M:`````````#(U;)Q6>CM[,[>1RVCX/M)ZM/O#J?=HVLOQ9NVV\WCGH?YG(%6
MI)N6:PE#UCGRBQP-.I<+Q8D%D`P4XIZ)!W#3(?_D#@N*$%?$N9Q`:G^:?+,!
MBV]_J9R;;L7?']EQ6!R[XY)\K$OCP-5DU'S@IP(*,V+;[7KP2FMGK\QF0D75
M[.-'Q@%]08[%P^4_+/+;TQWZH6Q@N8WQ#@````````````````````#B`@``
M```````````2````B`,`````````````$@```!\"`````````````!(````,
M```````````````@````*00`````````````$@```'D#`````````````!(`
M```X`0`````````````2````_0(`````````````$@```,X`````````````
M`!(```#I`@`````````````2````J@``````````````$@```#,!````````
M`````!(```"9`@`````````````2````-@,`````````````$@```*H"````
M`````````!(```"<`0`````````````2````1@,`````````````$@```#T#
M`````````````!(```!<`0`````````````2````W```````````````$@``
M`.8!`````````````!(```"#`0`````````````2````:`(`````````````
M$@```!<"`````````````!(```#&`@`````````````2````TP$`````````
M````$@```+<"`````````````!(```#?`0`````````````2````:@$`````
M````````$@```$T#`````````````!(````H```````````````@````>@(`
M````````````$@```%H#`````````````!(```!S```````````````2````
MU`(`````````````$@```(\#`````````````!(````0`@`````````````2
M````"@$`````````````$@```+D``````````````!(```"1`0``````````
M```2````VP(`````````````$@```+$"`````````````!(```"'`@``````
M```````2````.`(`````````````$@```+\"`````````````!(```!E````
M```````````2````/0$`````````````$@````0#`````````````!(```#(
M`0`````````````2````%P$`````````````$@```($#`````````````!(`
M``#-`@`````````````2````J@$`````````````$@```#<`````````````
M`"````#N```````````````2````>@$`````````````$@```&$#````````
M`````!(```#O`@`````````````2````@@``````````````$@```$L`````
M`````````"````!_`@`````````````2````)0,`````````````$@```"0"
M`````````````!(````2`P`````````````2````20(`````````````$@``
M`)`"`````````````!(````=`P`````````````2````:P,`````````````
M$@```$D!``#@F`0(`````!(```"A!```>,@$"`0````1`!``5P0``""W!`BM
M"P``$@`.`*@$``#0LP0(KP$``!(`#@``!```9,@$"``````2``\`HP,``$!!
M!0@$````(0`:``8$``#@L`0(!0```!(`#@"'!```\,<$"&$````2``X`F0``
M`)"9!`@`````$@```"@!``!(004(!````!$`&@!D!```'$$%"``````0`!D`
M+P,``$1!!0@$````$0`:`&8$```<004(`````"``&0"B`P``0$$%"`0````A
M`!H`]@,``&#(!`@"````$@`.`)<$```H004(!````!$`&0"]!```\+`$",@!
M```2``X`_0```$Q!!0@!````$0`:`*$#``!`004(!````!$`&@"<`P``<)H$
M"/,!```2``X`W`0``("U!`A$````$@`.`!<$``#0M00()````!(`#@`R!```
MX,8$"',````2``X`L@,``"Q!!0@`````$``:`+X#``"4404(`````!``&@!9
M`@``?,@$"`0````1`!``!@4``-#"!`@)!```$@`.`'$$```0L`0(P0```!(`
M#@!J!```8YP$"``````2``X`N`$``+"6!`@`````$@```$L$``#PL@0(X```
M`!(`#@"K`P``+$$%"``````0`!D`/@0``,"R!`@M````$@`.`.H$``!@QP0(
M20```!(`#@"U!```<*\$"#0````2``X`\0$``%!!!0@3````$0`:`,H$````
MM@0($@$``!(`#@"W!```^)4$"``````2``P``&QI8G!E<FPN<V\`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I
M<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y
M<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=U-6<'8`4&5R;%]N97=8
M4U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`
M<&5R;%]R=6X`4&5R;%]D;W5N=VEN9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U
M8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!0
M97)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L
M:6)P=&AR96%D+G-O+C``;W!E;C8T`&QS965K-C0`<F5A9`!P=&AR96%D7V=E
M='-P96-I9FEC`%]?97)R;F]?;&]C871I;VX`8VQO<V4`;&EB8RYS;RXV`%])
M3U]S=&1I;E]U<V5D`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?
M7W-T<F1U<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I
M<@!R96%L;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`
M<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C
M:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED
M`')E861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V
M-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M+W5S<B]L:6(O<&5R;#4O-2XR,"XQ+VDU.#8M;&EN=7@M=&AR96%D+6UU;'1I
M+T-/4D4`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S
M97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P87)?<&P`7V9P
M7VAW`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%
M05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR`$=,24)#
M7S(N,`!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0````"``(`
M`P````(``@`"``(````"```````$``(``@````(``@````````````4`!@`"
M`````@`"````!P````(``@````(``@`&``````````(``@`"``,``@``````
M!P```````@`"````````````"``'```````"``@``P`(``,``@`"``<````!
M``$``0`!``(``0`!```````!``(``0`"``$``0`!`````@`!``$``0`!``$`
M`0`!``$``0`!`````0`!``$``0`!`````0`!``$``@```@``$````#`````2
M:6D-```&`!P%```0````$&EI#0```P`F!0````````$`!0!/`@``$```````
M```2:6D-```(`!P%```0````=!EI"0``!P`P!0``$````'(9:0D```4`/`4`
M`!`````4:6D-```$`$@%```0````$&EI#0```@`F!0```````/P_!0@&'P``
M0$$%"`57``!$004(!5```$A!!0@%3@``3$$%"`56``!0004(!6@```Q`!0@'
M`0``$$`%"`<"```40`4(!P,``!A`!0@'!0``'$`%"`<&```@0`4(!P<``"1`
M!0@'"```*$`%"`<)```L0`4(!V(``#!`!0@'"@``-$`%"`<+```X0`4(!PP`
M`#Q`!0@'#0``0$`%"`<.``!$0`4(!P\``$A`!0@'$```3$`%"`<1``!00`4(
M!Q(``%1`!0@'$P``6$`%"`<4``!<0`4(!Q4``&!`!0@'%@``9$`%"`<7``!H
M0`4(!Q@``&Q`!0@'&0``<$`%"`<:``!T0`4(!QL``'A`!0@''```?$`%"`<=
M``"`0`4(!QX``(1`!0@''P``B$`%"`<@``",0`4(!R$``)!`!0@'(@``E$`%
M"`<C``"80`4(!R0``)Q`!0@')0``H$`%"`<F``"D0`4(!R<``*A`!0@'*```
MK$`%"`<I``"P0`4(!RH``+1`!0@'*P``N$`%"`=%``"\0`4(!RP``,!`!0@'
M+0``Q$`%"`<N``#(0`4(!R\``,Q`!0@',```T$`%"`<Q``#40`4(!S(``-A`
M!0@',P``W$`%"`<T``#@0`4(!S4``.1`!0@'30``Z$`%"`<W``#L0`4(!S@`
M`/!`!0@'.0``]$`%"`<Z``#X0`4(!SL``/Q`!0@'/0```$$%"`<^```$004(
M!S\```A!!0@'0```#$$%"`=!```0004(!T(``!1!!0@'0P``&$$%"`=$``!3
M@^P(Z(\&``"!P_^I``"+@_S___^%P'0%Z/H!``"#Q`A;PP``````_S4$0`4(
M_R4(0`4(`````/\E#$`%"&@`````Z>#_____)1!`!0AH"````.G0_____R44
M0`4(:!````#IP/____\E&$`%"&@8````Z;#_____)1Q`!0AH(````.F@____
M_R4@0`4(:"@```#ID/____\E)$`%"&@P````Z8#_____)2A`!0AH.````.EP
M_____R4L0`4(:$````#I8/____\E,$`%"&A(````Z5#_____)31`!0AH4```
M`.E`_____R4X0`4(:%@```#I,/____\E/$`%"&A@````Z2#_____)4!`!0AH
M:````.D0_____R5$0`4(:'````#I`/____\E2$`%"&AX````Z?#^____)4Q`
M!0AH@````.G@_O___R500`4(:(@```#IT/[___\E5$`%"&B0````Z<#^____
M)5A`!0AHF````.FP_O___R5<0`4(:*````#IH/[___\E8$`%"&BH````Z9#^
M____)61`!0AHL````.F`_O___R5H0`4(:+@```#I</[___\E;$`%"&C`````
MZ6#^____)7!`!0AHR````.E0_O___R5T0`4(:-````#I0/[___\E>$`%"&C8
M````Z3#^____)7Q`!0AHX````.D@_O___R6`0`4(:.@```#I$/[___\EA$`%
M"&CP````Z0#^____)8A`!0AH^````.GP_?___R6,0`4(:``!``#IX/W___\E
MD$`%"&@(`0``Z=#]____)91`!0AH$`$``.G`_?___R680`4(:!@!``#IL/W_
M__\EG$`%"&@@`0``Z:#]____):!`!0AH*`$``.F0_?___R6D0`4(:#`!``#I
M@/W___\EJ$`%"&@X`0``Z7#]____):Q`!0AH0`$``.E@_?___R6P0`4(:$@!
M``#I4/W___\EM$`%"&A0`0``Z4#]____);A`!0AH6`$``.DP_?___R6\0`4(
M:&`!``#I(/W___\EP$`%"&AH`0``Z1#]____)<1`!0AH<`$``.D`_?___R7(
M0`4(:'@!``#I\/S___\ES$`%"&B``0``Z>#\____)=!`!0AHB`$``.G0_/__
M_R740`4(:)`!``#IP/S___\EV$`%"&B8`0``Z;#\____)=Q`!0AHH`$``.F@
M_/___R7@0`4(:*@!``#ID/S___\EY$`%"&BP`0``Z8#\____)>A`!0AHN`$`
M`.EP_/___R7L0`4(:,`!``#I8/S___\E\$`%"&C(`0``Z5#\____)?1`!0AH
MT`$``.E`_/___R7X0`4(:-@!``#I,/S___\E_$`%"&C@`0``Z2#\____)0!!
M!0AHZ`$``.D0_/___R4$004(:/`!``#I`/S___\E"$$%"&CX`0``Z?#[____
M)0Q!!0AH``(``.G@^____R40004(:`@"``#IT/O___\E%$$%"&@0`@``Z<#[
M____)1A!!0AH&`(``.FP^___58GE5E.#Y/"#[#"-11")1"0(C44,B40D!(U%
M"(D$).BL_?__QT0D"."8!`C'1"0$X)@$",<$))"9!`CH`"T``(`]3$$%"`!U
M+NBR_/__A<"CD%$%"`^$C`$``(D$).C]^___H4A!!0B)!"3H,/___\:`!04`
M``"A2$$%"(D$).@<____@(BV`@```J%(004(B00DZ`C___\QTH"(M@(```&+
M10B)5"0<C4@%B4PD&-]L)!C8!6`G!0C=!6@G!0C9R=KIW^">#X<'`0``P>$"
MB0PDZ'G\__^+=0R+70C'!8A1!0@$````BQ:#^P&CA%$%",=`!%O*!`B)$(L5
M*$$%",=`#%[*!`B)4`BZ`0```'X5C;0F`````(L,EHE,D`R#P@$YVG7RQT28
M#`````"#PP.)1"0,H9!1!0B)7"0(QT0D$`````#'1"0$L*\$"(D$).AZ_?__
MA<")PW0ZH9!1!0B)!"3H1_O__XU4)"RX'\D$".B9#```A<!T+*&0404(B00D
MZ.CZ___H$_W__XUE^(G86UY=PZ&0404(B00DZ)W]__^)P^NUH8Q1!0B%P'0*
MB00DZ+@J``#KP8U4)"RXU,@$".A(#```A<"CC%$%"'2JZ]W'1"0$4$$%",<$
M),_(!`CH.?S__\<$)`$```#HO?O__S'M7HGA@^3P4%12:&#(!`AH\,<$"%%6
M:'":!`CHW/O___1FD&:09I!FD&:0D(L<),-FD&:09I!FD&:09I"X+T$%""TL
M004(@_@&=P'#N`````"%P'3V58GE@^P8QP0D+$$%"/_0R<.-M@````"X+$$%
M""TL004(P?@"B<+!ZA\!T-'X=0'#N@````"%TG3V58GE@^P8B40D!,<$)"Q!
M!0C_TLG#B?:-O"<`````@#UC004(`'4358GE@^P(Z'S____&!6-!!0@!R?/#
M9I"A\#X%"(7`=!^X`````(7`=!95B>6#[!C'!"3P/@4(_]#)Z7G___^0Z7/_
M__]FD)!55U93@>Q8`0``B40D"(U('#'`D(UT)@"+%($/RHE4A!B#P`&#^!!U
M[XU4)$R-C"1,`0``C70F`(M"[(/"!#-"_#-"T#-"R,'('XE""#G*=>>+1"0(
MBW`$BU`0BQB)\8MP"(E4)!0#5"08B?6+<`R)+"2)="0$BT0D!(G>P<X;C;PR
MF7F"6HG.B>KWT2'R(<@)T(GQBU0D!`''BP0DB=T#5"0<]]7!R0*)="00(>B)
MW2'+"=B)^XVT`IEY@EJ)ZL'+&P'>BQPD`UPD((GPP<@;B6PD#,'*`HG]C9P#
MF7F"6HGX]]`AU2'(">B)]0'#B?#!SP+WT`-,)"0A_2'0">B)W8V,`9EY@EJ)
MV,'(&P'!`U0D*(G(P<@;P<X"C90"F7F"6HG8]]`A]2'X">B)S0'"B<C!RP+W
MT`-\)"PAW2'P">B)U8V\!YEY@EJ)T,'(&P''`W0D,(GXP<@;P<D"C;0&F7F"
M6HG0]]`AS2'8">B)_0'&B?C!R@+WT`-<)#0AU2'(">B)]8V<`YEY@EJ)\,'(
M&P'#`TPD.(G8P<@;P<\"C8P!F7F"6HGP]]`A_2'0">B)W0'!B=C!S@+WT`-4
M)#PA]2'X">B)S8V4`IEY@EJ)R,'(&P'"`WPD0(G0P<@;P<L"C;P'F7F"6HG(
M]]`AW2'P">B)U0''B=#!R0+WT`-T)$0AS2'8">B)_8VT!IEY@EJ)^,'(&P'&
M`UPD2(GPP<@;P<H"C9P#F7F"6HGX]]`AU2'(">B)]0'#B?#!SP+WT`-,)$PA
M_2'0">B)W8V,`9EY@EJ)V,'(&P'!`U0D4(G(P<X"P<@;(?6-E`*9>8):B=CW
MT"'X">B)S0'"B<C!RP+WT`-\)%0AW2'P">B)U8V\!YEY@EJ)T,'(&P''`W0D
M6(GXP<@;P<D"C;0&F7F"6HG0]]`AS2'8">B)_0'&B?C!R@+WT`-<)%PAU2'(
M">B)]8V<`YEY@EJ)\,'(&P'#`TPD8(G8P<@;P<\"C8P!F7F"6HGP]]`A_2'0
M">B)W0'!B=C!S@+WT`-4)&0A]2'X">B-E`*9>8):B<C!RP+!R!L!PHG8`WPD
M:#'P,<C!R0*-O`>AZ]ENB=#!R!L!^(G/`W0D;#'?,=?!R@*-O#ZAZ]ENB<;!
MSAL!_HG7`UPD<#'/,<?!R`*-O#NAZ]ENB?/!RQL!^XG'`TPD=#'7,??!S@*-
MO#FAZ]ENB=G!R1L!^8GW`U0D>(G-,<<QW\'-&\'+`HV\.J'KV6Z)Z@'ZB=\#
M1"1\,?<QS\')`HV\.*'KV6Z)T,'(&P'XB<\#M"2`````,=\QU\'*`HV\/J'K
MV6Z)QL'.&P'^B=<#G"2$````,<\QQ\'(`HV\.Z'KV6Z)\\'+&P'[B<<#C"2(
M````,=<Q]\'.`HV\.:'KV6Z)V<')&P'YB?<#E"2,````,<>)S3'?P<T;C;PZ
MH>O9;HGJ`?K!RP(#A"20````B=\Q]S'/C;PXH>O9;HG0P<D"P<@;`?B)SP.T
M))0````QWS'7P<H"C;P^H>O9;HG&P<X;`?Z)UP.<))@````QSS''P<@"C;P[
MH>O9;HGSP<L;`?N)QP.,))P````QUS'WP<X"C;PYH>O9;HG9P<D;`?F)]P.4
M)*`````QQXG-,=_!S1O!RP*-O#JAZ]ENB>H!^HG?`X0DI````#'W,<_!R0*-
MO#BAZ]ENB=#!R!L!^(G/`[0DJ````#'?,=?!R@*-O#ZAZ]ENB<;!SAL!_HG7
M`YPDK````#'/,<?!R`*-O#NAZ]ENB?/!RQL!^XG'`XPDL````#'7,??!S@*-
MO#FAZ]ENB=G!R1L!^8GW`Y0DM````#''B<TQW\'-&XV\.J'KV6Z)Z@'ZB[PD
MN````,'+`HG=(?4!QXG8"?`AR`GH`[0DO````(V\!]R\&X^)T,')`L'(&XG-
M`?B)]XG.(=T)WB'6`YPDP`````GNC;PWW+P;CXG&P<H"P<X;B=4!_HG?B=,A
MS0G+(<,#C"3$````">N-O!_<O!N/B?/!R`+!RQN)Q0'[B<^)P2'5"=$A\0GI
MC;P/W+P;CXG9P<D;`?F+O"3(````P<X"B?4)Q0'7B>J)]2':(<4)ZHG-P<T;
MC;P7W+P;CXGJ`?J+O"3,````P<L"B=TA]0''B=@)\"'(`[0DT`````GHC;P'
MW+P;CXG0P<D"P<@;B<T!^(GWB<XAW0G>(=8#G"34````">Z-O#?<O!N/B<;!
MR@+!SAN)U0'^B=^)TR'-"<LAPP.,)-@````)ZXV\']R\&X^)\\'(`L'+&XG%
M`?N)SXG!(=4)T2'Q">F-O`_<O!N/B=G!R1L!^8N\)-P```#!S@*)]0G%`=>)
MZHGU(=HAQ0GJB<W!S1N-O!?<O!N/B>H!^HN\).````#!RP*)W2'U`<>)V`GP
M(<@#M"3D````">B-O`?<O!N/B=#!R0+!R!N)S0'XB?>)SB'="=XAU@.<).@`
M```)[HV\-]R\&X^)QL'*`L'.&XG5`?Z)WXG3(<T)RR'#">N-O!_<O!N/B?/!
MRQL!^\'(`@.,).P```")Q2'5B<^)P0G1(?$)Z8V\#]R\&X^)V<')&P'YB[PD
M\````,'.`HGU"<4!UXGJB?4AVB'%">J)S<'-&XV\%]R\&X^)Z@'ZB[PD]```
M`,'+`HG=(?4!QXG8"?`AR`.T)/@````)Z(V\!]R\&X^)T,')`L'(&XG-`?B)
M]XG.(=T)WB'6">Z-O#?<O!N/B<;!SAO!R@(!_@.<)/P```")U2'-B=^)TPG+
M(<,#C"0``0``">N-O!_<O!N/B?/!R`+!RQN)Q0'[B<^)P2'5"=$A\0GIC;P/
MW+P;CXG9P<D;`?F+O"0$`0``P<X"B?4)Q0'7B>J)]2':(<4)ZHG-P<L"P<T;
MC;P7W+P;CP'OB=T#A"0(`0``,?6)ZC'*C900UL%BRHGXP<D"P<@;B<T!T#'=
M`[0D#`$``(GJB<4Q^L'-&XVT%M;!8LJ)Z@'RB?[!S@(#G"00`0``B?<QSS''
MC;P[UL%BRHG3P<@"P<L;`?N)QP.,)!0!```Q]S'7P<H"C;PYUL%BRHG9P<D;
M`<^)T0.T)!@!```QP3'9P<L"C;0.UL%BRHGYP<D;`<Z)V0.$)!P!```QT3'Y
M`Y0D(`$``(V,"-;!8LJ)\,'(&\'/`@'!B?@QWS'WB<W!S@+!S1N-O#K6P6+*
M`>^)]0.<)"0!```QQ8GJB?TQRL'-&\')`HV<$];!8LJ)Z@':B<L#A"0H`0``
M,?,Q^\'/`HV<&-;!8LJ)T,'(&P'#B?@#M"0L`0``,<@QT,'*`HVT!M;!8LJ)
MV,'(&P'PB=8#C"0P`0``,?XQWL'+`HVT,=;!8LJ)P<')&P'.B=D#O"0T`0``
M,=$QP<'(`HV\#];!8LJ)\<')&P'YB<<#E"0X`0``,=\Q]XG-P<T;C;PZUL%B
MRL'.`@'OB?4#G"0\`0``,<6)ZHG],<K!S1O!R0*-G!/6P6+*B>H!VHG+`X0D
M0`$``#'S,?O!SP*-G!C6P6+*B=#!R!L!PXGX`[0D1`$``#'(,=#!R@*-M`;6
MP6+*B=C!R!L!\(G6`XPD2`$``#'^,=[!RP*-M#'6P6+*B<'!R1L!\8G>`[PD
M3`$``#'6,<;!R`*-O#?6P6+*B<[!SAL!_HG'`Y0D4`$``(GU,=\QS\'-&XV\
M.M;!8LJ)ZHML)`P#K"14`0```?K!R0*-O"O6P6+*B<TQQ8GKB=4Q\P'[BWPD
M",'-&P'KP<X"B1^+'"0#5"00`TPD!`-$)!2)5P2-%!Z)5PB)3PR)1Q"!Q%@!
M``!;7E]=PXUT)@"-O"<`````55=6B<93@^PLA<")5"0<=$NA0$$%"(7`B40D
M&'0^#[8&/#UU0S';BT0D&(LHA>UT*XG'D(UT)@")7"0(B70D!(DL).@H\?__
MA<!U!X!\'0`]="V#QP2++X7M==R#Q"PQP%M>7UW#9I"$P'2YB?.#PP$/M@,\
M/70$A,!U\BGSZZ>+1"0<B?DK3"08P?D"B0B#Q"R-1!T!6UY?7<.0C70F`%.)
MPX/L&(U4)`R)V.A/____A<!T-HUV`*%`004(BU0D#(T4D(M*!(7)B0ITV8UV
M`(/"!(M*!(7)B0IU](U4)`R)V.@9____A<!US8/$&%O#55>)QU8QP%.)TX/L
M/(`Z/0^4P`'#B1PDZ,/N__^-5"0LB<6)^.CF_O__A<")Q@^$W````(D$).BD
M[O__.<4/AK0```"+1"0LC0R%``````^V!SP]#X1F`0``A,`/A%X!``")^.L&
M9I"$TG0+@\`!#[80@/H]=?$I^(LU0$$%"(U$*`*)!"0!SNCC[?__A<")!@^$
M/`$``*%`004(C4\!BU0D+(L4D`^V!X3`B`)U&>L;C;0F`````(/!`0^V0?^#
MP@&$P(@"=`0\/77LQ@(],<"-M"8`````#[8,`XA,`@&#P`&$R77Q,<"#Q#Q;
M7E]=PXVT)@````"#PP$/MD/_@\8!A,"(1O]U[^O<D(UT)@"+%4!!!0B+`H7`
M#X2G````,?:-M@````"#Q@&+!+*%P'7VC02U"````(L-@%$%"(7)="V)1"0$
MB10DZ!'M__^%P*-`004(='N-#+4`````QT2P!`````")="0LZ=_^__^)!"2)
M5"08QP6`404(`0```.CJ[/__A<!T28M4)!B-#+4`````B4PD"(D$)(E,)!R)
M5"0$B40D&.A3Z___BT0D&(M,)!RC0$$%".NCC70F`#'`Z;+^__^X"````#'V
MZ6;___^X_____^D,____C78`55=6B<93@>R,````A<!T!8`X`'4+@<2,````
M6UY?7<.)!"3HV.[__X7`B<=TYXD\).@Z[O__A<")PP^$L````(![$RX/A,8`
M``")-"2-:Q/HJ^S__XDL)(E$)!SHG^S__XM,)!R-1`$"B00DZ!_L__^);"04
MB70D$,=$)`R`R`0(QT0D"/_____'1"0$`0```(D$)(G#Z'7N__^-1"0@B40D
M"(E<)`3'!"0#````Z/WM__^#^/]T$(M$)#`E`/```#T`0```='")'"3H\.K_
M_XD<).A8ZO__B3PDZ)#M__^%P(G##X56____C;8`````B3PDZ/CM__^)-"3H
M<.K__X'$C````%M>7UW#D(UT)@`/MD,4A,`/A!+___\\+@^%)O___X![%0`/
MA`#___]FD.D5____C78`B=CHP?[__Y#KCHVT)@````"-O"<`````5E.#[!2A
M2$$%"(D$).A>[?__BT!\BW`$H4A!!0B)!"3H2^W__P^V6&&A2$$%"(/C?XD$
M).@W[?__BT`$#[=`$,'@!PG89HE&`J%(004(B00DZ!KM__^+0'R+6`2A2$$%
M"(D$).@'[?__QT0D"`````#'1"0$5<H$"(D$).A?Z___B4,<H4A!!0B)!"3H
MW^S__XM`?(M8!*%(004(B00DZ,SL__^+@+@#``")0R"A2$$%"(D$).BV[/__
MBT!\BU@$H4A!!0B)!"3HH^S__S'2BX#8````A<!T%J%(004(B00DZ(KL__^+
M@-@```"+4'"A2$$%"(E3)(D$).AQ[/__BT!\BT`$QT`H`````*%(004(B00D
MZ%?L__^+0'R+0`3'0!@`````H4A!!0B)!"3H/>S__XM`?(M8!*%(004(B00D
MZ"KL__^+@.0!``")0RR#Q!1;7L.-="8`C;PG`````%.)PX/L&*%(004(B00D
MZ/WK__^)7"0$QP0D`P````7D````B40D".CTZ___A<!T"(/$&#'`6\.0H4A!
M!0B)!"3HR^O__XN`]````"4`\```/0!```!T'Z%(004(B00DZ*SK__^+@/0`
M```E`/```#T`H```=;J)'"3'1"0$`@```.C:ZO__A<`/E,"#Q!@/ML!;PXVV
M`````(V\)P````!5B=57B<=64X'L+!```(UT)!S'1"0(_P\``(ET)`3'!"2&
MR`0(9:$4````B80D'!```#'`Z&?H__^%P'YKC5C_@'P<'`!T68G#B5PD",=$
M)`0O````B30DZ`/J__^%P'1'H4A!!0B)!"3H`NO__XE<)`R)="0(B7PD!(D$
M).A^ZO__BX0D'!```&4S!10```!U-8'$+!```%M>7UW#C78`A=MUI8UT)@"A
M2$$%"(D$).B[ZO__B6PD"(E\)`2)!"3HZ^?__^N[Z(3G__^-="8`@^P<H4A!
M!0B)!"3HD.K__\=$)`R&R@0(QT0D"+"6!`C'1"0$E<@$"(D$).@`Z?__@\0<
MPXVV`````(V_`````(/L+*%(004(B00DZ%#J__^)!"3HJ/___Z%(004(B00D
MZ#OJ___'1"04`````,=$)!!5R@0(QT0D#%7*!`C'1"0(T,($",=$)`2QR`0(
MB00DZ$OI__^#Q"S#C;0F`````%=64X'L,"```&6A%````(F$)"P@```QP(U<
M)"KH?^?__\=$)!21R`0(QT0D#,;(!`C'1"0(`1```,=$)`0!````B1PDB40D
M$.@#ZO__A<!X9XV\)"L0``")'"3'1"0(`!```(E\)`3HQ.;__X7`B<-X1HU`
M`8D$).A3Y___A<")QG0UB5PD"(E\)`2)!"3H[>7__XGPQ@0>`(N4)"P@``!E
M,Q44````=1.!Q#`@``!;7E_#D(UT)@`QP.O=Z!_F___K#9"0D)"0D)"0D)"0
MD)#I*____XUT)@"-O"<`````55=64X'L/!```&6A%````(F$)"P0```QP(U4
M)"BXU,@$"(NT)%`0``"+O"14$```Z%OW___'1"0$+P```(DT)(G#Z/GF__^%
MP'0MB?*XW<@$".@I^/__B?"+C"0L$```93,-%`````^%5@$``('$/!```%M>
M7UW#B30DZ.#F__^)/"2-?"0LQT0D!.K(!`B)1"0<Z.CG__^)Q8M$)!R#P`&)
M1"0<C78`A>UTGX!]``!U!;W2R`0(A=MT%(EL)`2)'"3HB>3__X7`#X2L````
MB2PDZ(GF__^`?`7_+W419I"#Z`&`?`7_+\9$!0``=/&+3"0<C10!@?K_#P``
M#X])____B70D&,=$)!3LR`0(B6PD$,=$)`P0R@0(QT0D"``0``#'1"0$`0``
M`(D\).@^Z/__H4A!!0B)!"3HX>?__XE\)`3'!"0#````!>0```")1"0(Z+CG
M__^%P'4?H4A!!0B)!"3HM^?__XN`]````"4`\```/0"```!T&\=$)`3JR`0(
MQP0D`````.CQYO__B<7I$O___\=$)`0!````B3PDZ,KF__^%P'71B?JXW<@$
M".C*]O__B3PDZ"+F___IEO[__^@XY/__D(VT)@````"+1"0$#[8(A,ET((U0
M`>L*#[8*@\(!A,ET$8#Y+W7Q#[8*B="#P@&$R77O\\.-=@!3@^P8BUPD((7;
M=#R`.P!T-XD<).A'Y?__C40#_SG#<@[K49"-="8`@^@!.=AT"8`X+W3TZS=F
MD(`X+Y"-="8`#X6)````9I#'!"0"````Z)SD__^%P'1PNBX```!FB1"#Q!A;
MPXUV`(`X+W0'@^@!.<-R]#G8=0WKOHVV`````(`X+W4'@^@!.<-R]"G8C5`"
M@?H`$```=R^#P`&)7"0$QT0D#``0``")1"0(QP0D@$$%".B(Y?__@\08N(!!
M!0A;PXVV`````(/$&#'`6\/'1"0@[,@$"(/$&%OI`.7__U=6@^PT9:$4````
MB40D+#'`H63*!`B)1"0*H6C*!`B)1"0.H6S*!`B)1"02H7#*!`B)1"06H73*
M!`B)1"0:H7C*!`B)1"0>H7S*!`B)1"0BH8#*!`B)1"0F#[<%A,H$"&:)1"0J
MN.[(!`CHX?3__[CWR`0(Z-?T__^X_\@$".C-]/__N`C)!`CHP_3__[@/R00(
MZ+GT__^X'\D$".BO]/__N-3(!`CHI?3__[@KR00(Z)OT__^X-<D$".B1]/__
MN#_)!`CHA_3__[C=R`0(Z'WT__^X2<D$".AS]/__N%+)!`CH:?3__XU4)`2X
M7<D$".B[\___A<!T#(G"N#7)!`CHF_3__XU4)`2X;LD$".B=\___A<!T#(G"
MN(#)!`CH??3__XU4)`2XB\D$".A_\___A<!T,XG"N-3(!`CH7_3__[JWR00(
MN`_)!`CH4/3__XM$)"QE,P44````=4V#Q#1>7\.0C70F`(U4)`2XF\D$".@Z
M\___A<!T#HG"N"O)!`CH&O3__^NYC70D&[^LR00(N0H```#SIG6GC50D);@K
MR00(Z/CS___KE^AQX?__D*$D004(@_C_=`;#D(UT)@"#[!RX*\D$"(U4)`SH
MW_+__X7`=!L/MA`QP(32=`@QP(#Z,`^5P*,D004(@\0<PY`QP.ORC;8`````
MC;\`````@^P<Z"CA__^)!"3H@.#__X7`=`R+`(/$',.-M@`````QP.ORC;8`
M````C;\`````55>_P\D$"%93N[G)!`B#[$S'1"0DP\D$"(UT)"S'1"0HN<D$
M",=$)"S&R00(QT0D,+S)!`C'1"0TP<D$",=$)#C3R00(QT0D/`````#K(I"+
M1"1@B2PDB40D!.C0W___A<!T/(7;="Z+!HG?@\8$B<.-5"0@B?CH!/+__X7`
MB<5T!8`X`'7)BU0D8(GXZ-[R__^%VW72@\1,6UY?7<-FD(M$)&")!"3HI.'_
M_XDL)(E$)!SHF.'__XM4)!R-1`("B00DZ!CA__^);"08QT0D%.K(!`C'1"0,
M$,H$",=$)`C_____QT0D!`$```")PHM$)&")%"2)5"0<B40D$.A>X___BU0D
M'(GXZ&/R___I4O___XVT)@````"-O"<`````55=64X'L+($``&6A%````(F$
M)!R!```QP(U4)$BXU,@$"(NL)$"!``#'1"1,ZLD$",=$)%#2R`0(QT0D5```
M``#'1"1D@,D$",=$)&AYR00(QT0D;._)!`C'1"1PELD$",=$)'3WR00(QT0D
M>`````#'1"18WLD$",=$)%S[R00(QT0D8`````#HTO#__X7`=`F`.``/A5T$
M``"0C70F`.@+_O__A<")PP^$9@0``(D<).AYX/__C40``8D$).C]W___@#L`
MB<:)QW0VC70F``^V`X/#`8D\)(/'`L=$)`P$R@0(QT0D"/____^)1"00QT0D
M!`$```#H0^+__X`[`'7.C7PD:+B`R00(ZPV-=@"#QP2+1_R%P'0NC50D2.@]
M\/__A<")PW3G@#@`=.+HK?7__X7`=-F)'"3H<>#__X7`B<%U38UV`(M<)$R%
MVW1`@#L`OP$```!U%NLTC70F`(M<O$R%VW0H@\<!@#L`="")V.AI]?__A<!T
MY8D<).@MX/__A<!TV8G!ZP>0C70F`#')B0PDB?.)3"0PZ)#?__^+3"0PBSN#
MPP2-E__^_O[WUR'Z@>*`@("`=.GWPH"```!U!L'J$(/#`@#2@]L#*?.-G`,$
M!```B1PDB4PD-.C=WO__BTPD-(ET)!S'1"08"<H$",=$)!3LR`0(B4PD$,=$
M)`P.R@0(B<;'1"0(_____\=$)`0!````B00DB40D,.@;X?__QT0D!,`!``")
M-"3H:]___X/X_P^$@@```*%(004(B00DZ*7@___'!"0#````!>0```")1"0(
MBT0D,(E$)`3HF.#__X7`#X28````BT0D,(E$)!"+10#'1"0(S,H$",=$)`0!
M````B40D#*%$004(B00DZ!3@__\QP(N,)!R!``!E,PT4````#X7N"```@<0L
M@0``6UY?7<.-=@#H"]___XL`@_@1#X1N____B40D%(M$)#")1"00BT4`QT0D
M")#*!`C'1"0$`0```(E$)`RA1$$%"(D$).BPW___,<#KFHUT)@"A2$$%"(D$
M).C;W___BX#T````)0#P```]`$````^%1?___Z%(004(B00DZ+C?__^+L/P`
M``#HG=S__SG&#X4E____H4A!!0B)!"3HF-___XN`]````"7_`0``/<`!```/
MA0+___^)'"3H2MW__XU4)$B)1"0XN+S)!`CHV.W__X7`#X05"```B00DZ!C>
M__^)1"0$BT4`B00DZ"GV__^%P(G##X3T!P``B1PDZ'?=__^#^`-^*HUT`_R_
M%\H$"+D%````\Z9U&(/X!`^$M@8``(!\`_LO#X2K!@``C70F`.AS^O__A<!U
M',=$)`0`````B1PDZ$_=__^%P(E$)#0/A5<!``"ZM\D$"+@KR00(Z#3N__\Q
MV^AMW/__BWPD,(MT)#C'1"0<5<H$",=$)!3LR`0(B7PD$,=$)`PPR@0(B40D
M&,=$)`C_____QT0D!`$```")-"3HW=[__^M1C78`Z&/=__^#.!%U6>@9W/__
M@\,!QT0D(%7*!`B)7"0<QT0D%.S(!`B)?"00QT0D##[*!`B)1"08QT0D"/__
M___'1"0$`0```(DT).B*WO__QT0D!,`!``")-"3HVMS__X/X_W2=BT0D,(D$
M).B)VO__BW0D.+C4R`0(B?+H:>W__XDT).CQ^?__B?#IJ/W__V:0B00DB40D
M,.C<^?__BT0D,(D$).B@W/__Z8G]__^XWLD$"+X!````ZQ*-M"8`````BT2T
M6(/&`87`="6-5"1(Z"3L__^%P'3H@#@`=..)!"3H8]S__X7`=->)P^E7^___
ML`V[X\D$".E7^___QT0D#`(```")QL=$)`3N____QT0D"/____^)!"3H^MK_
M_XV$)!P!``#'1"0(!@```(E$)`2)-"3HC]G__X"\)!P!````=0Z`O"0=`0``
M0P^$5`4``(M$)#3'1"0,`````,=$)`0`````QT0D"`````")!"3HH]K__\>$
M)+P````!(T5GQX0DP````(FKS>_'A"3$````_MRZF,>$),@```!V5#(0QX0D
MS````/#ATL/'A"30`````````,>$)-0`````````QX0D&`$```````"-=@"-
MA"0<`0``B40D!(M$)#3'1"0(`(```(D$).C9V/__A<")Q0^.U@$``(N4)-``
M``"-!.HYP@^'M0$``(N4)-0```")A"30````B>C!Z!T!T(F$)-0```"+A"08
M`0``A<`/A'H!``"Z0````(GN*<(YU7X"B=:-A`38````C8PD'`$``(ET)`B)
M3"0$B00DZ*78__^+A"08`0```?"#^$")A"08`0``#X54____C80D'`$``"GU
M`<:-A"2\````Z$7?__^0C70F`(/]/P^.X````(/M0(GWB>C!Z`:)1"0\P>`&
MC5P&0&:0BP>#QT")A"38````BT?$B80DW````(M'R(F$).````"+1\R)A"3D
M````BT?0B80DZ````(M'U(F$).P```"+1]B)A"3P````BT?<B80D]````(M'
MX(F$)/@```"+1^2)A"3\````BT?HB80D``$``(M'[(F$)`0!``"+1_")A"0(
M`0``BT?TB80D#`$``(M'^(F$)!`!``"+1_R)A"04`0``C80DO````.ARWO__
M.=\/A4K___^+?"0\B?B#P`'!X`;!YP8!QBG]C80DV````,=$)`Q$````B6PD
M"(ET)`2)!"3HV-C__XFL)!@!``#I)/[__XUT)@"-M"0<`0``Z=S^__^-="8`
MBXPDU````(U1`>E#_O__BT0D-(D$).C-VO__BYPDT````(NT)-0```")V,'H
M`X/@/XU0`8/Z.,:$!-@```"`#X];`@``NC<````IPHV$!-D```")5"0(QT0D
M!`````")!"3H`=G__XGPP>@8B(0D$`$``(GPP>@0B(0D$0$``(GPP>@(B(0D
M$@$``(GPB(0D$P$``(G8P>@8B(0D%`$``(G8P>@0B(0D%0$``(G8P>@(B(0D
M%@$``(V$)+P```"(G"07`0``C;0DDP```.A&W?__BY0DO````(GWC:PD@```
M`(V<)+L```")T<'I&`^VP8A,)'^)T<'I$(B,)(````")T8B4)((```"+E"3`
M````P>D(B(PD@0```(G1P>D8B(PD@P```(G1P>D0B(PDA````(G1B)0DA@``
M`(N4),0```#!Z0B(C"2%````B='!Z1B(C"2'````B='!Z1"(C"2(````B=&(
ME"2*````BY0DR````,'I"(B,)(D```")T<'I&(B,)(L```")T<'I$(B,)(P`
M``")T8B4)(X```"+E"3,````P>D(B(PDC0```(G1P>D8B(PDCP```(G1P>D0
MB(PDD````(G1P>D(B(PDD0```(B4))(```#I#@```(VT)@`````/MD4`@\4!
MB3PD@\<"B40D$,=$)`P$R@0(QT0D"/_____'1"0$`0```.@"V?__.=]USL:$
M)+L`````QT0D'%7*!`B)="08BT0D,,=$)!3LR`0(QT0D#"'*!`C'1"0(____
M_XE$)!"+1"0XQT0D!`$```")!"3HMMC__^D\^O__BVT$A>T/A$[Y__^)+"3H
MCM;__X/X`P^&/?G__XUT!?R_',H$"+D%````\Z8/A2?Y__^)Z^D@^?__NC\`
M```IPHV$!-D```")5"0(QT0D!`````")!"3HIM;__XV$)+P```#H2MO__XV4
M)-@```"Y#@```#'`B=?SJ^F"_?__@+PD'@$``$$/A9[Z__^`O"0?`0``0P^%
MD/K__X"\)"`!``!(#X6"^O__@+PD(0$``$4/A73Z__^+="0TQT0D#`(```#'
M1"0$QO___\=$)`C_____B30DZ!?5__^-A"0<`0``QT0D""D```")1"0$B30D
MZ*S3__^-A"0<`0``QT0D'%7*!`B)1"08Z;K^__^-="8`Z"O4__^+70#I!/C_
M_XUV`%575E.#["RA2$$%"(D$).@LU___C50D',9`70&X#\D$".B*Y?__A<!T
M"8`X,0^$=0(``.C(\/__H4A!!0B)!"3H^];__\=$)`P+````QT0D"`$```#'
M1"0$3\H$"(D$).B[U/__A<`/A,L```"+0`R#/8A1!0@!BW@8#XZX````,?:[
M`0```.LQC;0F`````(M%#(E$)`2AA%$%"(L$F(D$).C)TO__A<!U?:&(404(
M@\,!@\8!.=A^<Z%(004(B00DZ'G6___'1"0,`````(ET)`B)?"0$B00DZ-'5
M__^%P'1%BRB+10@E``0@`#T`!```=)RA2$$%"(D$).@_UO__QT0D#`(```#'
M1"0(`````(EL)`2)!"3H<]/__^EQ____C;8`````H8A1!0B-4/\Y\@^$,`$`
M`*%(004(B00DZ/O5___'1"0,`P```,=$)`@!````QT0D!%3*!`B)!"3HN]/_
M_X7`B<-T-8M`#(LPH4A!!0B)!"3HP]7__\=$)`A6R@0(B70D!(D$).COTO__
MBT,,BQCV0PI`#X5+`@``H4A!!0B)!"3HD]7__\=$)`P#````QT0D"`$```#'
M1"0$6\D$"(D$).A3T___A<")QG0ZC50D'+C=R`0(Z,_C__^%P(G##X15`0``
MBT8,BSBA2$$%"(D$).A#U?__B5PD"(E\)`2)!"3H<]+__Z%(004(B00DZ";5
M__^-5"0<QD!=`+C4R`0(Z(3C__^%P(G#HXQ1!0@/A'T```#'1"0$P`$``(D$
M).BET___@_@1=`R-4`&#^@$/AW`!``"#Q"Q;7E]=PXUT)@"#^`$/CL?^__^[
M`0```&:0H4A!!0B#PP&)!"3HN-3__XE\)`2)!"3H/-'__SD=B%$%"'_<Z9?^
M__^-M"8`````@'@!``^$AOW__^E\_?__D*&$404(B00DZ(OQ__^%P*.,404(
M#X3N````BT8,BSV$404(BQB+0P@E``0@`#T`!```#X6B````BT,,B7PD!(D$
M).AAT?__B<>+1@R+&(M3"('B``0@`('Z``0``'50BT,,B40D"*&$404(B7PD
M#(L`QP0D1,L$"(E$)`3HA]+__XVT)@````"AA%$%"(LXBT8,BQBA2$$%"(D$
M).CGT___B?J)V.ANZ/__Z:;^__^A2$$%"(D$).C,T___QT0D#`(```#'1"0(
M`````(E<)`2)!"3H`-'__^N(H4A!!0B)!"3HH=/__\=$)`P"````QT0D"```
M``")7"0$B00DZ-70___I,____\<$)"#+!`CH]-'__XE$)`RAA%$%"(E<)`B+
M`,<$)&S+!`B)1"0$Z-71__^A2$$%"(D$).A(T___B5PD!(D$).A,TO__Z9?]
M__^-M"8`````5E.#[!2+="0@B30DZ/_K__\/M@B)PX3)="&-4`'K"Y`/M@J#
MP@&$R701@/DO=?$/M@J)TX/"`83)=>_H8.[__X7`=!V%]G09@#X`=!3'1"0$
M"<H$"(D<).CSSO__.=AT!H/$%%M>PX/$%(GP6U[I_>/__XVV`````(V\)P``
M``"#[!RA2$$%"(D$).B@TO__QT0D!/____^)!"3H`-#__Z%(004(B00DZ(/2
M___'1"0(`````,=$)`2@K`0(B00DZ#O2__^#Q!S#9I!FD&:0D%/HVM3__X'#
M2G@``(/L&(N#(`$``(E$)`R+1"0HB40D"(M$)"2)1"0$BT0D((D$).BKS___
M@\086\-FD&:09I!55S'_5E/HE=3__X'#!7@``(/L'(ML)#"-L^S^___HY<W_
M_XV#Z/[__RG&P?X"A?9T)XVV`````(M$)#B)+"2)1"0(BT0D-(E$)`3_E+OH
M_O__@\<!.?=UWX/$'%M>7UW#ZPV0D)"0D)"0D)"0D)"0\\,``%.#[`CH(]3_
M_X'#DW<``(/$"%O#`P````$``@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`
M+W!R;V,O)6DO)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU
M3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!0
M05)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?
M05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!3
M2$Q)0E]0051(`%5315(`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4DY!
M344`)3`R>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E
M<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`
M+64`+2T`````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```'!E
M<FQX<VDN8P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C
M=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI
M"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@`````C(2]U<W(O8FEN+W!E<FP*979A
M;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@
M7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY
M(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC
M;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q
M=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E
M('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R
M(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@
M(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A
M<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E
M;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E
M9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R
M92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@
M<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U
M<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI
M;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL
M"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*
M("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@
M(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@
M4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@
M("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP
M)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R
M96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D
M=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@
M(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@
M('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*
M7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!]
M(&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.
M5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*
M("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H
M:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%2
M7T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E
M0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-
M86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M
M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F
M:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O
M<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H
M7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@
M<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<
M;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?
M1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@
M)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T
M:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E
M7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68[
M"B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN
M+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL
M92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN
M="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@
M("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD
M(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE
M;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@
M("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@
M(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@
M("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T
M("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@
M("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE
M(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@
M("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO
M8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I
M(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@
M("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@
M("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@
M("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN
M960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[
M)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@
M("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?
M=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@
M("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F
M:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D
M;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R
M8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@
M8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I
M;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA
M;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*
M("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL
M97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S
M<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(
M96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D
M=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C
M(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL
M96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@
M("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE
M("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U
M:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@
M("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@
M("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53
M=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@
M(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]
M?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@
M("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U
M;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!
M4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U
M<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E
M>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T
M;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI
M;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V
M97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D
M(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!0
M4D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N
M('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C
M(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@
M96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@
M("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*
M("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M
M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@
M("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@
M("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@
M("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@
M("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@
M("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@
M/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@
M("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@
M("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@
M("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@
M("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'
M5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@
M("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]
M"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*
M"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*
M("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?
M7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF
M("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D
M<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@
M8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD[
M"@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G
M)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*
M("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A
M<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@
M("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@
M("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I
M;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D
M<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@
M("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@
M("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O
M<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE
M9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?
M1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H
M<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]
M?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G
M:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@
M?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@
M("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@
M:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@
M("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@
M(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@
M("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@
M/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A
M+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L
M92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@
M("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W
M.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\
M+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@
M("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G
M<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@
M9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H
M87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@
M("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A
M;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[
M)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E
M;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@
M("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE
M(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@
M("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH
M7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@
M("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@
M("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@
M96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@
M("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@
M("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@
M("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E
M;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U
M=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R
M968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@
M("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@
M)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@
M("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@
M1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A
M(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E
M($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@
M("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&
M24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT
M9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC
M;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*
M("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT
M96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@
M("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T
M:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA
M;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E
M<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N
M(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@
M("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L
M(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@
M>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE
M7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@
M?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H
M+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I
M;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P
M-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R
M97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@
M(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R
M;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U
M="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*
M("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@
M("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>
M3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@
M("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B
M)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[
M"B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O
M"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@
M("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA
M;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@
M("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T
M<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E
M('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@
M("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]
M?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H
M;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E
M4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@
M1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL
M93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK
M<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R![
M"B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@
M;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$
M>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S
M=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S
M.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*
M("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@
M("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C
M.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@
M("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*
M("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE
M879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@
M>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*
M("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*
M"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD
M<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3
M971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E
M;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q
M.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H
M("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@
M+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D
M=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N
M;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@
M9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@
M(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA
M;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@
M<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I
M9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["B`@("`@
M("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!
M4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=
M*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X
M+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@
M("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@
M("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$
M:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@
M(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD
M(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@
M("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@
M(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@
M("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X
M+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*
M"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@
M("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@
M*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*
M("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE
M(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL
M96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F
M+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P
M96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@
M8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M
M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA
M;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H
M)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@
M("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*
M("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?
M5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I
M<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@
M/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@
M("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@
M("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I
M.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI
M;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@
M("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@
M("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE4
M24%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@
M>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F
M;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@
M)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E
M>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@
M)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.
M5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U
M8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@
M("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,
M14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF
M("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G
M9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?
M7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF
M:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I
M;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I
M92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M
M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M
M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?
M7T5.1%]?"@``````````````@/___\]!`1L#.^@````<````L&[__P0!````
M<___G`4``/!U__\H`0``$('__V@!``"P@?__O`$```""___@`0``X(/__R`"
M```PA?__>`(``)"&__^D`@``,(?__]`"````B/__$`,``$"(__\H`P``H(C_
M_T`#``!PB?__>`,``(")__^,`P``4(O__\P#``"`B___X`,``&",__\@!```
M$([__U`$``!@CO__;`0``)".__^(!```L(___\@$``!@F___#`4``'"?__],
M!0``\)___X0%``!`H/__R`4``("@___H!0``\*#__R0&```4``````````%Z
M4@`!?`@!&PP$!(@!```@````'````*1M__]0!`````X(1@X,2@\+=`1X`#\:
M.RHR)"(\````0````,!T__\5"P```$$."(4"00X,AP-!#A"&!$$.%(,%1@[L
M`@,&"PX40<,.$$'&#@Q!QPX(0<4.!```4````(````"@?___FP````!!#@B%
M`D$.#(<#00X0A@1##A2#!4,.0`)6"@X40\,.$$'&#@Q!QPX(0<4.!$,+:@X4
M1<,.$$'&#@Q!QPX(0<4.!```(````-0```#L?___4`````!!#@B#`D4.(`)(
M#@A!PPX$````/````/@````8@/__W0$```!!#@B%`D$.#(<#0PX0A@1##A2#
M!44.4`+?"@X40<,.$$'&#@Q!QPX(0<4.!$@+`%0````X`0``N('__T(!````
M00X(A0)!#@R'`T$.$(8$0PX4@P5&#J`!3PH.%$'##A!!Q@X,0<<."$'%#@1!
M"P+F"@X40<,.$$'&#@Q!QPX(0<4.!$8+```H````D`$``+""__]5`0```$$.
M"(8"00X,@P-##B`#30$.#$'##@A!Q@X$`"@```"\`0``Y(/__Y,`````00X(
M@P)%#B!M"@X(0\,.!$(+`E8."$3##@0`/````.@!``!8A/__S`````!!#@B%
M`D,.#(<#0PX0A@1!#A2#!48.P"`"B@H.%$'##A!!Q@X,0<<."$'%#@1$"Q0`
M```H`@``Z(3__S0`````0PX@<`X$`!0```!``@``$(7__UD`````0PXP`E4.
M!#0```!8`@``6(7__\$`````00X(AP)!#@R&`T$.$(,$1@[`0`*F"@X00<,.
M#$'&#@A!QPX$1@L`$````)`"``#PA?__!0`````````\````I`(``.R%___(
M`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@[0(`)I"@X40<,.$$'&#@Q!QPX(
M0<4.!$$+$````.0"``!\A___+0`````````\````^`(``)B'___@`````$$.
M"(,"0PX@`E\*#@A!PPX$1`L"4PH."$;##@1'"T,*#@A#PPX$00M+#@A!PPX$
M+````#@#```XB/__KP$```!!#@B'`D$.#(8#0PY``UL!"@X,0<8."$''#@1&
M"P``&````&@#``"XB?__1`````!3#B!K"@X$0@L``!@```"$`P``[(G__R0`
M````0PX@5@H.!$<+```\````H`,```"*__\2`0```$$."(4"00X,AP-&#A"&
M!$$.%(,%2`Y@`H@*#A1!PPX00<8.#$''#@A!Q0X$0PL`0````.`#``#@BO__
MK0L```!!#@B%`D$.#(<#00X0A@1!#A2#!48.P(("`ZX""@X40<,.$$'&#@Q!
MQPX(0<4.!$0+```\````)`0``$R6__\)!````$$."(4"00X,AP-!#A"&!$$.
M%(,%0PY``U@""@X40<,.$$'&#@Q!QPX(0<4.!$4+-````&0$```<FO__<P``
M``!!#@B&`D$.#(,#0PX@`E\*#@Q!PPX(0<8.!$$+0PX,0\,."$'&#@04````
MG`0``&2:__])`````$,.(`)%#@0H````M`0``%QM___S`0```$$."(4"0@T%
M2(8#@P0#B`$*PT'&0<4,!`1!"QP```#@!```<)K__SH`````00X(@P).#B!I
M#@A!PPX$.``````%``"0FO__80````!!#@B%`D$.#(<#0PX0A@1!#A2#!4X.
M,`)(#A1!PPX00<8.#$''#@A!Q0X$$````#P%``#$FO__`@``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`#"=!`@0G00(``````$````!`````0`````"```!````3P(``!T```##`P``
M#````/B5!`@-````9,@$"!D```#H/@4(&P````0````:````[#X%"!P````$
M````!````*R!!`CU_O]OY(0$"`4```#PC`0(!@```$"&!`@*````4@4```L`
M```0````%0`````````#`````$`%"`(````@`@``%````!$````7````V),$
M"!$```"HDP0($@```#`````3````"````/[__V\8DP0(____;P(```#P__]O
M0I($"```````````````````````````````````````````````````````
M``````````````#T/@4(```````````VE@0(1I8$"%:6!`AFE@0(=I8$"(:6
M!`B6E@0(II8$"+:6!`C&E@0(UI8$".:6!`CVE@0(!I<$"!:7!`@FEP0(-I<$
M"$:7!`A6EP0(9I<$"':7!`B&EP0(EI<$"*:7!`BVEP0(QI<$"-:7!`CFEP0(
M]I<$"`:8!`@6F`0()I@$"#:8!`A&F`0(5I@$"&:8!`AVF`0(AI@$"):8!`BF
MF`0(MI@$",:8!`C6F`0(YI@$"/:8!`@&F00(%ID$"":9!`@VF00(1ID$"%:9
M!`AFF00(=ID$"(:9!`B6F00(IID$"+:9!`C&F00(UID$".:9!`CVF00(!IH$
M"!::!`@FF@0(-IH$"$::!`A6F@0(9IH$"```````````_____[#+!`A'0T,Z
M("A355-%($QI;G5X*2`T+C@N,R`R,#$T,#8R-R!;9V-C+31?."UB<F%N8V@@
M<F5V:7-I;VX@,C$R,#8T70``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````
M````````````````````````````````````````````"P````$````"````
M5($$"%0!```3```````````````!`````````!,````'`````@```&B!!`AH
M`0``(```````````````!``````````A````!P````(```"(@00(B`$``"0`
M``````````````0`````````.`````4````"````K($$"*P!```X`P``!@``
M```````$````!````#0```#V__]O`@```.2$!`CD!```7`$```8`````````
M!`````0````^````"P````(```!`A@0(0`8``+`&```'`````0````0````0
M````1@````,````"````\(P$"/`,``!2!0`````````````!`````````$X`
M``#___]O`@```$*2!`A"$@``U@````8``````````@````(```!;````_O__
M;P(````8DP0(&!,``)`````'`````@````0`````````:@````D````"````
MJ),$"*@3```P````!@`````````$````"````',````)`````@```-B3!`C8
M$P``(`(```8````-````!`````@```!\`````0````8```#XE00(^!4``",`
M``````````````0`````````=P````$````&````()8$""`6``!0!```````
M```````0````!````((````!````!@```'":!`AP&@``\BT`````````````
M$`````````"(`````0````8```!DR`0(9$@``!0```````````````0`````
M````C@````$````"````>,@$"'A(``#X7@`````````````(`````````)8`
M```!`````@```'`G!0APIP``[```````````````!`````````"D`````0``
M``(```!<*`4(7*@``%`%``````````````0`````````K@````X````#````
MZ#X%".BN```$```````````````$`````````+H````/`````P```.P^!0CL
MK@``!```````````````!`````````#&`````0````,```#P/@4(\*X```0`
M``````````````0`````````RP````8````#````]#X%"/2N```(`0``!P``
M```````$````"````-0````!`````P```/P_!0C\KP``!```````````````
M!`````0```#9`````0````,`````0`4(`+```!P!``````````````0````$
M````X@````$````#````'$$%"!RQ```0```````````````$`````````.@`
M```(`````P```$!!!0@LL0``5!``````````````(`````````#M`````0``
M`#``````````++$``$(```````````````$````!`````0````,`````````
<`````&ZQ``#V```````````````!````````````
